terminado: Tornado websocket backend for the term.js Javascript terminal emulator library
=========================================================================================

Description
-----------

This is a Tornado websocket backend for the term.js Javascript terminal
emulator library.

It evolved out of pyxterm, which was part of GraphTerm (as lineterm.py),
v0.57.0 (2014-07-18), and ultimately derived from the public-domain
Ajaxterm code, v0.11 (2008-11-13) (also on Github as part of QWeb).
